@@ -1,6 +1,9 @@
 """
     Implements creation of an object.
 """
+from django.core.management.color import no_style
+from django.db import connection
+
 from slumber.operations import ModelOperation
 from slumber.operations.instancedata import instance_data
 from slumber.server.http import require_permission
@@ -20,6 +23,12 @@ class CreateInstance(ModelOperation):
             instance = self.model.model(**dict([(k, v)
                 for k, v in request.POST.items()]))
             instance.save()
+            # Reset the sequence point in case there was a PK set
+            cursor = connection.cursor()
+            lines = connection.ops.sequence_reset_sql(
+                no_style(), [self.model.model])
+            cursor.execute(';'.join(lines))
+            # Return the
             return instance_data(response, self.model, instance)
         return do_create(self, request)
 
